@@ -34,7 +34,7 @@ class ASHRATT(ASH):
     '''
     @staticmethod
     def match(data):
-        return re.match(r'^\d{6}\.\d{3}$', data[1])
+        return re.match(r'^\d{6}\.\d{2,3}$', data[1])
 
     def __init__(self, *args, **kwargs):
         self.subtype = 'ATT'
