@@ -181,6 +181,26 @@ class GNS(TalkerSentence, LatLonFix):
         ('Differential reference station ID', 'diferential'),
     )
 
+class GRS(TalkerSentence):
+    """ Order of satellites will match those in the last GSA
+    """
+    fields = (
+        ('Timestamp', 'timestamp', timestamp),
+        ('Residuals mode', 'residuals_mode', int),
+        ('SV 01 Residual (m)', 'sv_res_01', float),
+        ('SV 02 Residual (m)', 'sv_res_02', float),
+        ('SV 03 Residual (m)', 'sv_res_03', float),
+        ('SV 04 Residual (m)', 'sv_res_04', float),
+        ('SV 05 Residual (m)', 'sv_res_05', float),
+        ('SV 06 Residual (m)', 'sv_res_06', float),
+        ('SV 07 Residual (m)', 'sv_res_07', float),
+        ('SV 08 Residual (m)', 'sv_res_08', float),
+        ('SV 09 Residual (m)', 'sv_res_09', float),
+        ('SV 10 Residual (m)', 'sv_res_10', float),
+        ('SV 11 Residual (m)', 'sv_res_11', float),
+        ('SV 12 Residual (m)', 'sv_res_12', float),
+    )
+
 class BWW(TalkerSentence):
     """ Bearing, Waypoint to Waypoint
     """
