@@ -105,10 +105,11 @@ def test_srf():
     data = '$PSRF999,0,1200,8,1,1'
     msg = pynmea2.parse(data)
     assert type(msg) == pynmea2.srf.SRF
+    assert msg.render(checksum=False) == data
 
 
 def test_grm():
-    data = ' $PGRME,15.0,M,45.0,M,25.0,M*1C'
+    data = '$PGRME,15.0,M,45.0,M,25.0,M*1C'
     msg = pynmea2.parse(data)
     assert type(msg) == pynmea2.grm.GRME
     assert msg.sentence_type == 'GRME'
@@ -118,6 +119,8 @@ def test_grm():
     assert msg.vpe_unit == 'M'
     assert msg.osepe == 25.0
     assert msg.osepe_unit == 'M'
+    assert msg.render() == data
+
 
 def test_tnl():
     data = '$PTNL,BPQ,224445.06,021207,3723.09383914,N,12200.32620132,W,EHT-5.923,M,5*60'
@@ -126,15 +129,19 @@ def test_tnl():
     assert msg.datestamp == datetime.date(2007,12,2)
     assert msg.latitude == 37.384897319
     assert msg.longitude == -122.00543668866666
+    assert msg.render() == data
 
 
 def test_ubx00():
     data = '$PUBX,00,074440.00,4703.74203,N,00736.82976,E,576.991,D3,2.0,2.0,0.091,0.00,-0.032,,0.76,1.05,0.65,14,0,0*70'
     msg = pynmea2.parse(data)
     assert type(msg) == pynmea2.ubx.UBX00
+    assert msg.identifier() == 'PUBX'
+    assert msg.ubx_type == '00'
     assert msg.timestamp == datetime.time(7, 44, 40)
     assert msg.latitude == 47.06236716666667
     assert msg.lat_dir == 'N'
+    assert msg.render() == data
 
 
 def test_ubx03():
@@ -142,6 +149,7 @@ def test_ubx03():
     msg = pynmea2.parse(data)
     assert type(msg) == pynmea2.ubx.UBX03
     assert msg.num_sv == 20
+    assert msg.render() == data
 
 
 def test_ubx04():
@@ -151,6 +159,7 @@ def test_ubx04():
     assert msg.date == datetime.date(2014, 10, 13)
     assert msg.time == datetime.time(7, 38, 24)
     assert msg.clk_bias == 495176
+    assert msg.render() == data
 
 
 def test_create():
@@ -171,3 +180,78 @@ def test_unknown_sentence():
     assert msg.manufacturer == 'ZZZ'
     assert msg.data == ['ABC', '1', '2', '3']
     assert msg.render(checksum=False, dollar=False) == data
+
+
+def test_proprietary_VTX_0002():
+    # A sample proprietary sentence from a Vectronix device (laser distance)
+    data = "$PVTX,0002,181330,00005.22,M,262.518,T,-01.967,09.358,W*7E"
+    msg = pynmea2.parse(data)
+    assert msg.manufacturer == 'VTX'
+    assert msg.dist == 5.22
+    assert msg.direction == 262.518
+    assert msg.va == -1.967
+    assert msg.render() == data
+
+
+def test_proprietary_VTX_0012():
+    # A sample proprietary sentence from a Vectronix device (target position)
+    data = "$PVTX,0012,177750,3348.5861,N,10048.5861,W,00045.2,M,038.8,M*22"
+    msg = pynmea2.parse(data)
+    assert msg.manufacturer == 'VTX'
+    assert msg.latitude == 33.80976833333333
+    assert msg.longitude == -100.80976833333334
+    assert msg.altitude == 45.2
+    assert msg.gain == 38.8
+    assert msg.render() == data
+
+
+def test_proprietary_GRMW():
+    # A sample proprietary Garmin Waypoint sentence, generated by DIREWOLF
+    data = "$PGRMW,AC7FD-1,,000A,AC7FD local DIGI U=12.5V|T=23.9C*1A"
+    msg = pynmea2.parse(data)
+    assert msg.manufacturer == 'GRM'
+    assert msg.wname == 'AC7FD-1'
+    assert msg.altitude == None
+    assert msg.symbol == '000A'
+    assert msg.comment == 'AC7FD local DIGI U=12.5V|T=23.9C'
+
+
+def test_proprietary_MGNWPL():
+    # A sample proprietary Magellan Waypoint sentence, generated by DIREWOLF
+    data = "$PMGNWPL,4531.7900,N,12253.4800,W,,M,AC7FD-1,AC7FD local DIGI U=12.5V|T=23.9C,c*46"
+    msg = pynmea2.parse(data)
+    assert msg.manufacturer == 'MGN'
+    assert msg.lat =='4531.7900'
+    assert msg.lat_dir == 'N'
+    assert msg.lon == '12253.4800'
+    assert msg.lon_dir == 'W'
+    assert msg.altitude == None
+    assert msg.altitude_unit == 'M'
+    assert msg.wname == 'AC7FD-1'
+    assert msg.comment == 'AC7FD local DIGI U=12.5V|T=23.9C'
+    assert msg.icon == 'c'
+    assert msg.latitude == 45.529833333333336
+    assert msg.longitude == -122.89133333333334
+
+
+def test_KWDWPL():
+    # A sample proprietary Kenwood Waypoint sentence, generated by DIREWOLF
+    data = "$PKWDWPL,053125,V,4531.7900,N,12253.4800,W,,,200320,,AC7FD-1,/-*10"
+    msg = pynmea2.parse(data)
+    assert msg.manufacturer == "KWD"
+    assert msg.timestamp == datetime.time(5, 31, 25)
+    assert msg.status == 'V'
+    assert msg.is_valid == False
+    assert msg.lat == '4531.7900'
+    assert msg.lat_dir == 'N'
+    assert msg.lon == '12253.4800'
+    assert msg.lon_dir == 'W'
+    assert msg.sog == None
+    assert msg.cog == None
+    assert msg.datestamp == datetime.date(2020, 3, 20)
+    assert msg.datetime == datetime.datetime(2020, 3, 20, 5, 31, 25)
+    assert msg.altitude == None
+    assert msg.wname == 'AC7FD-1'
+    assert msg.ts == '/-'
+    assert msg.latitude == 45.529833333333336
+    assert msg.longitude == -122.89133333333334
